# Adult/ Census Income Data

## Source / Data Set Description:
<https://archive.ics.uci.edu/ml/datasets/adult>

This dataset is used to predict whether income exceeds $50K/yr. Contains 48842 instances, mix of continuous and discrete. `adult.data` contains
the first 32561 instances which comprise the original training set while
`adult.test` contains an additional 16281 instances which comprise the original
test set.

Information about dataset features is provided in `adult.names`

## Download instructions

Download the following files and place them as-is in the current folder

1. [adult.data](https://archive.ics.uci.edu/ml/machine-learning-databases/adult/adult.data)

2. [adult.test](https://archive.ics.uci.edu/ml/machine-learning-databases/adult/adult.test)

3. [adult.names](https://archive.ics.uci.edu/ml/machine-learning-databases/adult/adult.names)

## Relevant Papers

* Ron Kohavi, "Scaling Up the Accuracy of Naive-Bayes Classifiers: a Decision-Tree Hybrid", Proceedings of the Second International Conference on Knowledge Discovery and Data Mining, 1996 